library(testthat)
library(loon.tourr)

testthat::test_check("loon.tourr")
